@@ -18,7 +18,7 @@ And then these normal Py3 imports work on both Py3 and Py2::
     import winreg    # on Windows only
     import test.support
     import html, html.parser, html.entites
-    import http, http.client
+    import http, http.client, http.server
     import _thread
     import _dummythread
     import _markupbase
@@ -50,7 +50,7 @@ Limitations
 -----------
 We don't currently support these modules, but would like to::
 
-    import http.server, http.cookies, http.cookiejar
+    import http.cookies, http.cookiejar
     import dbm
     import dbm.dumb
     import dbm.gnu
@@ -66,7 +66,7 @@ We don't currently support these modules, but would like to::
 
 Notes
 -----
-This module only supports Python 2.6 and Python 3.1+.
+This module only supports Python 2.6, Python 2.7, and Python 3.1+.
 
 The following renames are already supported on Python 2.7 without any
 additional work from us::
@@ -76,7 +76,7 @@ additional work from us::
     StringIO.StringIO -> io.StringIO
     Bytes.BytesIO -> io.BytesIO
 
-Old things that can perhaps be fixed for people by futurize.py::
+Old things that can one day be fixed automatically by futurize.py::
 
   string.uppercase -> string.ascii_uppercase   # works on either Py2.7 or Py3+
   sys.maxint -> sys.maxsize      # but this isn't identical
@@ -93,6 +93,7 @@ from __future__ import absolute_import, print_function
 import sys
 import logging
 import imp
+import contextlib
 
 from future import utils
 
@@ -173,6 +174,7 @@ RENAMES = {
            'future.standard_library._markupbase': '_markupbase',
           }
 
+
 REPLACED_MODULES = set(['test', 'urllib', 'pickle'])  # add dbm when we support it
 # These are entirely new to Python 2.x, so they cause no potential clashes
 #   xmlrpc, tkinter, http, html
@@ -245,6 +247,7 @@ class RenameImport(object):
         module_info = imp.find_module(name, path)
         return imp.load_module(name, *module_info)
 
+
 # (New module name, new object name, old module name, old object name)
 MOVES = [('collections', 'UserList', 'UserList', 'UserList'),
          ('collections', 'UserDict', 'UserDict', 'UserDict'),
@@ -311,8 +314,10 @@ MOVES = [('collections', 'UserList', 'UserList', 'UserList'),
          # urlparse.urlunsplit	urllib.parse
         ]
 
+
 _old_sys_meta_path = sys.meta_path
 
+
 def enable_hooks():
     if utils.PY3:
         return
@@ -324,9 +329,22 @@ def enable_hooks():
 
     sys.meta_path = [RenameImport(RENAMES)]
 
+
 def disable_hooks():
     if not utils.PY3:
         sys.meta_path = _old_sys_meta_path
 
+
+@contextlib.contextmanager
+def suspend_hooks():
+    disable_hooks()
+    try:
+        yield
+    except Exception as e:
+        raise e
+    finally:
+        enable_hooks()
+
+
 if not utils.PY3:
     enable_hooks()
